import { aws_apigateway as apigateway, aws_elasticloadbalancingv2 as elb, aws_route53 as route53 } from "aws-cdk-lib";
import { IVpc, SubnetSelection } from "aws-cdk-lib/aws-ec2";
import { Construct } from "constructs";
/**
 * Properties for InternalService
 */
export interface InternalServiceProps {
    /**
     * VPC attached to the application load balancer.
     */
    readonly vpc: IVpc;
    /**
     * Subnets attached to the application load balancer.
     */
    readonly subnetSelection: SubnetSelection;
    /**
     * VPC endpoint ip addresses attached to the load balancer`s target group
     */
    readonly vpcEndpointIPAddresses: Array<string>;
    /**
     * List of alternative domains attached to the solution.
     */
    readonly subjectAlternativeNames: string[];
    /**
     * Subdomain attached to hosted zone name.
     */
    readonly subDomain: string;
    /**
     * Hosted zone that will be used for the custom domain.
     */
    readonly hostedZone: route53.IHostedZone;
    /**
     * SSLPolicy attached to the load balancer listener.
     *
     * @default elb.SslPolicy.FORWARD_SECRECY_TLS12_RES_GCM
     */
    readonly loadBalancerListenerSSLPolicy?: elb.SslPolicy;
    /**
     * SSLPolicy attached to the apigateway custom domain.
     *
     * @default apigateway.SslPolicy.TLS_1_2
     */
    readonly customDomainSSLPolicy?: apigateway.SecurityPolicy;
}
export declare class InternalService extends Construct {
    /**
     * List of domains created by the internal service stack and shared with the api gateway stack.
     */
    readonly domains: apigateway.IDomainName[];
    constructor(scope: Construct, id: string, props: InternalServiceProps);
}
